# TMVA linear discriminators

import ROOT
 
ROOT.TMVA.Tools.Instance()
 
# note that it seems to be mandatory to have an
# output file, just passing None to TMVA::Factory(..)
# does not work. Make sure you don't overwrite an
# existing file.

fin = ROOT.TFile.Open("ntuple.root")
ntuple = fin.Get('ntuple')
ntuple.Print()

fout = ROOT.TFile("TMVA.root","RECREATE")

dataloader = ROOT.TMVA.DataLoader("dataset");
factory = ROOT.TMVA.Factory("TMVAClassification", fout,
                            ":".join([
                                "!V",
                                "!Silent",
                                "Color",
                                "DrawProgressBar",
                                "Transformations=I;D;P;G,D",
                                "AnalysisType=Classification"]
                                     ))

dataloader.AddVariable("x","F")
dataloader.AddVariable("y","F") 
 
dataloader.AddSignalTree(ntuple,1.0)
dataloader.AddBackgroundTree(ntuple,1.0)
 
# cuts defining the signal and background sample
sigCut = ROOT.TCut("signal > 0.5")
bgCut = ROOT.TCut("signal <= 0.5")
 
dataloader.PrepareTrainingAndTestTree(sigCut,   # signal events
                                   bgCut,    # background events
                                   ":".join([
                                        "nTrain_Signal=0",
                                        "nTrain_Background=0",
                                        "SplitMode=Random",
                                        "NormMode=NumEvents",
                                        "!V"
                                       ]))

method = factory.BookMethod(dataloader,ROOT.TMVA.Types.kCuts, "Cuts",
                   ":".join([
                       "!H",
                       "!V",
                       "FitMethod=MC:EffSel:SampleSize=200000:VarProp=FSmart",
                       ]))
 

method = factory.BookMethod(dataloader,ROOT.TMVA.Types.kCuts, "CutsPCA",
                   ":".join([
                       "!H",
                       "!V",
                       "FitMethod=MC:EffSel:SampleSize=200000:VarProp=FSmart:VarTransform=P",
                       ]))
 

method = factory.BookMethod(dataloader,ROOT.TMVA.Types.kCuts, "CutsD",
                   ":".join([
                       "!H",
                       "!V",
                       "FitMethod=MC:EffSel:SampleSize=200000:VarProp=FSmart:VarTransform=D",
                       ]))

factory.BookMethod(dataloader, ROOT.TMVA.Types.kFisher, 'Fisher',
        '!H:!V:Fisher') 

factory.BookMethod(dataloader, ROOT.TMVA.Types.kFisher, 'FisherD',
        '!H:!V:Fisher:VarTransform=D') 


factory.BookMethod(dataloader, ROOT.TMVA.Types.kFisher, 'FisherPCA',
        '!H:!V:Fisher:VarTransform=P') 

#non-linear !!!  BDT
factory.BookMethod(dataloader, ROOT.TMVA.Types.kBDT, "BDT",
                   ":".join([
                       "!H",
                       "!V",
                       "NTrees=850",
                       "nEventsMin=150",
                       "MaxDepth=3",
                       "BoostType=AdaBoost",
                       "AdaBoostBeta=0.5",
                       "SeparationType=GiniIndex",
                       "nCuts=20",
                       "PruneMethod=NoPruning",
                       ]))

factory.TrainAllMethods()
factory.TestAllMethods()
factory.EvaluateAllMethods()

#TMVA::TMVAGui()
#ROOT.TMVA.TMVAGui()




